pub struct RotateSampler { /* private fields */ }Expand description
A sampler that returns durations from a fixed list in a cyclic (rotating) order.
Note
This sampler maintains internal state (next_index). If you re-instantiate
this sampler frequently, the sequence will always start from the beginning.
Implementations
Sourceimpl RotateSampler
impl RotateSampler
Sourcepub fn new(
duration_list: impl IntoIterator<Item = PendingDuration>,
) -> RotateSampler
pub fn new( duration_list: impl IntoIterator<Item = PendingDuration>, ) -> RotateSampler
Creates a new RotateSampler starting from the first element.
Sourcepub fn new_with_index(
duration_list: impl IntoIterator<Item = PendingDuration>,
next_index: usize,
) -> RotateSampler
pub fn new_with_index( duration_list: impl IntoIterator<Item = PendingDuration>, next_index: usize, ) -> RotateSampler
Creates a new RotateSampler starting from a specific index.
Sourcepub fn peek_next_index(&self) -> usize
pub fn peek_next_index(&self) -> usize
Returns the index of the next duration to be sampled.
Sourcepub fn item_count(&self) -> usize
pub fn item_count(&self) -> usize
Returns the total number of items in the rotation list.