UniformSampler

Struct UniformSampler 

pub struct UniformSampler { /* private fields */ }
A sampler that draws from a continuous uniform distribution within [lower_bound, higher_bound).

Implementations

Source

impl UniformSampler

pub fn new(lower_bound: f64, higher_bound: f64) -> Result<UniformSampler, Error>

Creates a new UniformSampler with the given range. Returns an error if the range is empty or if values are non-finite.