pub trait TimeTrigger {
// Required methods
fn get_active_index(&self, now: SimTime) -> usize;
fn max_possible_index_hint(&self) -> usize;
}Expand description
A trait to determine which sampler should be active based on the current simulation time.
Required Methods
Sourcefn get_active_index(&self, now: SimTime) -> usize
fn get_active_index(&self, now: SimTime) -> usize
Returns the index of the sampler that should be active at the given simulation time.
Sourcefn max_possible_index_hint(&self) -> usize
fn max_possible_index_hint(&self) -> usize
Returns a hint about the maximum possible index to allow for pre-check optimizations.